local luasnip = require 'luasnip'
local cmp = require 'cmp'
cmp.setup {
  snippet = {
    expand = function(args)
      luasnip.lsp_expand(args.body)
    end,
  },
  mapping = {
    ['<C-p>'] 		= cmp.mapping.select_prev_item(),
    ['<C-n>'] 		= cmp.mapping.select_next_item(),
    ['<C-d>'] 		= cmp.mapping.scroll_docs(-4),
    ['<C-f>'] 		= cmp.mapping.scroll_docs(4),
    ['<C-Space>'] 	= cmp.mapping.complete(),
    ['<C-e>'] 		= cmp.mapping.close(),
    ['<CR>'] 		= cmp.mapping.confirm {
      behavior = cmp.ConfirmBehavior.Replace,
      select = true,
    },
    ['<Tab>'] = function(fallback)
      if cmp.visible() then
        cmp.select_next_item()
      elseif luasnip.expand_or_jumpable() then
        luasnip.expand_or_jump()
      else
        fallback()
      end
    end,
    ['<S-Tab>'] = function(fallback)
      if cmp.visible() then
        cmp.select_prev_item()
      elseif luasnip.jumpable(-1) then
        luasnip.jump(-1)
      else
        fallback()
      end
    end,
  },
  sources = {
    { name = 'nvim_lsp' },
    { name = 'luasnip' },
  },
}

require('nvim-autopairs').setup{}
cmp.event:on(
	'confirm_done',
	require('nvim-autopairs.completion.cmp').on_confirm_done({
		map_char = { tex = '' }
	})
)

-- require'lspconfig'.pylsp.setup{}

-- Add additional capabilities supported by nvim-cmp
local capabilities = vim.lsp.protocol.make_client_capabilities()
capabilities = require('cmp_nvim_lsp').update_capabilities(capabilities)

local lspconfig = require('lspconfig')

-- Enable some language servers with the additional completion capabilities offered by nvim-cmp
local servers = { 'clangd', 'rust_analyzer', 'pylsp', 'tsserver' }
for _, lsp in ipairs(servers) do
  lspconfig[lsp].setup {
    capabilities = capabilities,
  }
end
